Skip to main content Crate fresh_core Copy item path Source action api Plugin API: Safe interface for plugins to interact with the editor command config Configuration types shared across crates file_explorer file_uri Lightweight file path ↔ file:// URI conversion. hooks Hook System: Event subscription and notification for plugins menu overlay plugin_schemas Validation, default extraction, and merging for plugin-provided
config schemas. services text_property Text properties for embedding metadata in text ranges BufferId Unique identifier for a buffer ContainerId A split container that holds two children (internal node in the split tree) CursorId Unique identifier for a cursor LeafId A split pane that displays a buffer (leaf node in the split tree) SplitId Unique identifier for a split pane (leaf or container) TerminalId Unique identifier for a terminal session WindowId Unique identifier for an editor Window — a project-rooted unit
of editor state (file tree, LSP set, splits, buffer set, …) that
the user can switch between as a whole. Modelled on a VS Code
window. See docs/internal/orchestrator-sessions-design.md. WindowTerminalId A terminal identified across the whole editor. SplitDirection Direction of a split