pub enum Action {
Show 251 variants
InsertChar(char),
InsertNewline,
InsertTab,
MoveLeft,
MoveRight,
MoveUp,
MoveDown,
MoveWordLeft,
MoveWordRight,
MoveLineStart,
MoveLineEnd,
MovePageUp,
MovePageDown,
MoveDocumentStart,
MoveDocumentEnd,
SelectLeft,
SelectRight,
SelectUp,
SelectDown,
SelectWordLeft,
SelectWordRight,
SelectLineStart,
SelectLineEnd,
SelectDocumentStart,
SelectDocumentEnd,
SelectPageUp,
SelectPageDown,
SelectAll,
SelectWord,
SelectLine,
ExpandSelection,
BlockSelectLeft,
BlockSelectRight,
BlockSelectUp,
BlockSelectDown,
DeleteBackward,
DeleteForward,
DeleteWordBackward,
DeleteWordForward,
DeleteLine,
DeleteToLineEnd,
DeleteToLineStart,
TransposeChars,
OpenLine,
Recenter,
SetMark,
Copy,
CopyWithTheme(String),
Cut,
Paste,
YankWordForward,
YankWordBackward,
YankToLineEnd,
YankToLineStart,
AddCursorAbove,
AddCursorBelow,
AddCursorNextMatch,
RemoveSecondaryCursors,
Save,
SaveAs,
Open,
SwitchProject,
New,
Close,
CloseTab,
Quit,
Revert,
ToggleAutoRevert,
FormatBuffer,
GotoLine,
ScanLineIndex,
GoToMatchingBracket,
JumpToNextError,
JumpToPreviousError,
SmartHome,
DedentSelection,
ToggleComment,
DabbrevExpand,
SetBookmark(char),
JumpToBookmark(char),
ClearBookmark(char),
ListBookmarks,
ToggleSearchCaseSensitive,
ToggleSearchWholeWord,
ToggleSearchRegex,
ToggleSearchConfirmEach,
StartMacroRecording,
StopMacroRecording,
PlayMacro(char),
ToggleMacroRecording(char),
ShowMacro(char),
ListMacros,
PromptRecordMacro,
PromptPlayMacro,
PlayLastMacro,
PromptSetBookmark,
PromptJumpToBookmark,
Undo,
Redo,
ScrollUp,
ScrollDown,
ShowHelp,
ShowKeyboardShortcuts,
ShowWarnings,
ShowLspStatus,
ClearWarnings,
CommandPalette,
ToggleLineWrap,
ToggleReadOnly,
TogglePageView,
SetPageWidth,
InspectThemeAtCursor,
SelectTheme,
SelectKeybindingMap,
SelectCursorStyle,
SelectLocale,
NextBuffer,
PrevBuffer,
SwitchToPreviousTab,
SwitchToTabByName,
ScrollTabsLeft,
ScrollTabsRight,
NavigateBack,
NavigateForward,
SplitHorizontal,
SplitVertical,
CloseSplit,
NextSplit,
PrevSplit,
IncreaseSplitSize,
DecreaseSplitSize,
ToggleMaximizeSplit,
PromptConfirm,
PromptConfirmWithText(String),
PromptCancel,
PromptBackspace,
PromptDelete,
PromptMoveLeft,
PromptMoveRight,
PromptMoveStart,
PromptMoveEnd,
PromptSelectPrev,
PromptSelectNext,
PromptPageUp,
PromptPageDown,
PromptAcceptSuggestion,
PromptMoveWordLeft,
PromptMoveWordRight,
PromptDeleteWordForward,
PromptDeleteWordBackward,
PromptDeleteToLineEnd,
PromptCopy,
PromptCut,
PromptPaste,
PromptMoveLeftSelecting,
PromptMoveRightSelecting,
PromptMoveHomeSelecting,
PromptMoveEndSelecting,
PromptSelectWordLeft,
PromptSelectWordRight,
PromptSelectAll,
FileBrowserToggleHidden,
PopupSelectNext,
PopupSelectPrev,
PopupPageUp,
PopupPageDown,
PopupConfirm,
PopupCancel,
ToggleFileExplorer,
ToggleMenuBar,
ToggleTabBar,
FocusFileExplorer,
FocusEditor,
FileExplorerUp,
FileExplorerDown,
FileExplorerPageUp,
FileExplorerPageDown,
FileExplorerExpand,
FileExplorerCollapse,
FileExplorerOpen,
FileExplorerRefresh,
FileExplorerNewFile,
FileExplorerNewDirectory,
FileExplorerDelete,
FileExplorerRename,
FileExplorerToggleHidden,
FileExplorerToggleGitignored,
LspCompletion,
LspGotoDefinition,
LspReferences,
LspRename,
LspHover,
LspSignatureHelp,
LspCodeActions,
LspRestart,
LspStop,
ToggleInlayHints,
ToggleMouseHover,
ToggleLineNumbers,
ToggleScrollSync,
ToggleMouseCapture,
ToggleDebugHighlights,
SetBackground,
SetBackgroundBlend,
SetTabSize,
SetLineEnding,
ToggleIndentationStyle,
ToggleTabIndicators,
ResetBufferSettings,
DumpConfig,
Search,
FindInSelection,
FindNext,
FindPrevious,
FindSelectionNext,
FindSelectionPrevious,
Replace,
QueryReplace,
MenuActivate,
MenuClose,
MenuLeft,
MenuRight,
MenuUp,
MenuDown,
MenuExecute,
MenuOpen(String),
SwitchKeybindingMap(String),
PluginAction(String),
LoadPluginFromBuffer,
OpenSettings,
CloseSettings,
SettingsSave,
SettingsReset,
SettingsToggleFocus,
SettingsActivate,
SettingsSearch,
SettingsHelp,
SettingsIncrement,
SettingsDecrement,
OpenTerminal,
CloseTerminal,
FocusTerminal,
TerminalEscape,
ToggleKeyboardCapture,
TerminalPaste,
ShellCommand,
ShellCommandReplace,
ToUpperCase,
ToLowerCase,
CalibrateInput,
None,
}Expand description
High-level actions that can be performed in the editor
Variants
InsertChar(char)
InsertNewline
InsertTab
MoveLeft
MoveRight
MoveUp
MoveDown
MoveWordLeft
MoveWordRight
MoveLineStart
MoveLineEnd
MovePageUp
MovePageDown
MoveDocumentStart
MoveDocumentEnd
SelectLeft
SelectRight
SelectUp
SelectDown
SelectWordLeft
SelectWordRight
SelectLineStart
SelectLineEnd
SelectDocumentStart
SelectDocumentEnd
SelectPageUp
SelectPageDown
SelectAll
SelectWord
SelectLine
ExpandSelection
BlockSelectLeft
BlockSelectRight
BlockSelectUp
BlockSelectDown
DeleteBackward
DeleteForward
DeleteWordBackward
DeleteWordForward
DeleteLine
DeleteToLineEnd
DeleteToLineStart
TransposeChars
OpenLine
Recenter
SetMark
Copy
CopyWithTheme(String)
Cut
Paste
YankWordForward
YankWordBackward
YankToLineEnd
YankToLineStart
AddCursorAbove
AddCursorBelow
AddCursorNextMatch
RemoveSecondaryCursors
Save
SaveAs
Open
SwitchProject
New
Close
CloseTab
Quit
Revert
ToggleAutoRevert
FormatBuffer
GotoLine
ScanLineIndex
GoToMatchingBracket
JumpToNextError
JumpToPreviousError
SmartHome
DedentSelection
ToggleComment
DabbrevExpand
Cycle through dabbrev completions (Emacs Alt+/ style). Unlike popup-based completion, this inserts the best match directly and cycles through alternatives on repeated invocations.
SetBookmark(char)
JumpToBookmark(char)
ClearBookmark(char)
ListBookmarks
ToggleSearchCaseSensitive
ToggleSearchWholeWord
ToggleSearchRegex
ToggleSearchConfirmEach
StartMacroRecording
StopMacroRecording
PlayMacro(char)
ToggleMacroRecording(char)
ShowMacro(char)
ListMacros
PromptRecordMacro
PromptPlayMacro
PlayLastMacro
PromptSetBookmark
PromptJumpToBookmark
Undo
Redo
ScrollUp
ScrollDown
ShowHelp
ShowKeyboardShortcuts
ShowWarnings
ShowLspStatus
ClearWarnings
CommandPalette
ToggleLineWrap
ToggleReadOnly
TogglePageView
SetPageWidth
InspectThemeAtCursor
SelectTheme
SelectKeybindingMap
SelectCursorStyle
SelectLocale
NextBuffer
PrevBuffer
SwitchToPreviousTab
SwitchToTabByName
ScrollTabsLeft
ScrollTabsRight
SplitHorizontal
SplitVertical
CloseSplit
NextSplit
PrevSplit
IncreaseSplitSize
DecreaseSplitSize
ToggleMaximizeSplit
PromptConfirm
PromptConfirmWithText(String)
PromptConfirm with recorded text for macro playback
PromptCancel
PromptBackspace
PromptDelete
PromptMoveLeft
PromptMoveRight
PromptMoveStart
PromptMoveEnd
PromptSelectPrev
PromptSelectNext
PromptPageUp
PromptPageDown
PromptAcceptSuggestion
PromptMoveWordLeft
PromptMoveWordRight
PromptDeleteWordForward
PromptDeleteWordBackward
PromptDeleteToLineEnd
PromptCopy
PromptCut
PromptPaste
PromptMoveLeftSelecting
PromptMoveRightSelecting
PromptMoveHomeSelecting
PromptMoveEndSelecting
PromptSelectWordLeft
PromptSelectWordRight
PromptSelectAll
FileBrowserToggleHidden
PopupSelectNext
PopupSelectPrev
PopupPageUp
PopupPageDown
PopupConfirm
PopupCancel
ToggleFileExplorer
ToggleMenuBar
ToggleTabBar
FocusFileExplorer
FocusEditor
FileExplorerUp
FileExplorerDown
FileExplorerPageUp
FileExplorerPageDown
FileExplorerExpand
FileExplorerCollapse
FileExplorerOpen
FileExplorerRefresh
FileExplorerNewFile
FileExplorerNewDirectory
FileExplorerDelete
FileExplorerRename
FileExplorerToggleHidden
FileExplorerToggleGitignored
LspCompletion
LspGotoDefinition
LspReferences
LspRename
LspHover
LspSignatureHelp
LspCodeActions
LspRestart
LspStop
ToggleInlayHints
ToggleMouseHover
ToggleLineNumbers
ToggleScrollSync
ToggleMouseCapture
ToggleDebugHighlights
SetBackground
SetBackgroundBlend
SetTabSize
SetLineEnding
ToggleIndentationStyle
ToggleTabIndicators
ResetBufferSettings
DumpConfig
Search
FindInSelection
FindNext
FindPrevious
FindSelectionNext
FindSelectionPrevious
Replace
QueryReplace
MenuActivate
MenuClose
MenuLeft
MenuRight
MenuUp
MenuDown
MenuExecute
MenuOpen(String)
SwitchKeybindingMap(String)
PluginAction(String)
LoadPluginFromBuffer
OpenSettings
CloseSettings
SettingsSave
SettingsReset
SettingsToggleFocus
SettingsActivate
SettingsSearch
SettingsHelp
SettingsIncrement
SettingsDecrement
OpenTerminal
CloseTerminal
FocusTerminal
TerminalEscape
ToggleKeyboardCapture
TerminalPaste
ShellCommand
ShellCommandReplace
ToUpperCase
ToLowerCase
CalibrateInput
None