Module command

Module command 

Structs

Command
A command registered by a plugin via the service bridge. This is a simplified version that the editor converts to its internal Command type.
Suggestion
A single suggestion item for autocomplete

Enums

CommandSource
Source of a command (builtin or from a plugin)