pub struct TextProperty {
pub start: usize,
pub end: usize,
pub properties: HashMap<String, Value>,
}Expand description
A text property that associates metadata with a range of text
Fields
start: usizeStart byte offset (inclusive)
end: usizeEnd byte offset (exclusive)
properties: HashMap<String, Value>Arbitrary properties as key-value pairs
Implementations
Sourceimpl TextProperty
impl TextProperty
Sourcepub fn with_property(self, key: impl Into<String>, value: Value) -> Self
pub fn with_property(self, key: impl Into<String>, value: Value) -> Self
Add a property
Sourcepub fn with_properties(self, props: HashMap<String, Value>) -> Self
pub fn with_properties(self, props: HashMap<String, Value>) -> Self
Set multiple properties at once
Sourcepub fn contains(&self, pos: usize) -> bool
pub fn contains(&self, pos: usize) -> bool
Check if this property range contains a byte position
Sourcepub fn overlaps(&self, range: &Range<usize>) -> bool
pub fn overlaps(&self, range: &Range<usize>) -> bool
Check if this property range overlaps with another range
Sourcepub fn get_as<T: for<'de> Deserialize<'de>>(&self, key: &str) -> Option<T>
pub fn get_as<T: for<'de> Deserialize<'de>>(&self, key: &str) -> Option<T>
Get a property as a specific type